==> maverik-5.4.tar.gz: maverik-5.4/src/extras/VRML97/vrmlnodes.h <==
/*
 GNU Maverik - a system for managing display and interaction in 
               Virtual Environment applications.
 Copyright (C) 1999-2000 Advanced Interfaces Group

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA


 The authors can be contacted via:
 www   - http://aig.cs.man.ac.uk
 email - maverik@aig.cs.man.ac.uk
 mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
         University of Manchester, Manchester, M13 9PL, UK
*/


#include "mavlib_cvcomp.h"

/******************************************************************
*
*	VRML library for C++
*
*	Copyright (C) Satoshi Konno 1996-1997
*
*	File:	vrmlnodes.h
*
******************************************************************/

#ifndef _VRMLNODE_H_
#define _VRMLNODE_H_

#include "RootNode.h"
#include "DefNode.h"

#include "AnchorNode.h"
#include "AppearanceNode.h"
#include "AudioClipNode.h"
#include "BackgroundNode.h"
#include "BillboardNode.h"
#include "BoxNode.h"
#include "CollisionNode.h"
#include "ColorNode.h"
#include "ColorInterpolatorNode.h"
#include "ConeNode.h"
#include "CoordinateNode.h"
#include "CoordinateInterpolatorNode.h"
#include "CylinderNode.h"
#include "CylinderSensorNode.h"
#include "DirectionalLightNode.h"
#include "ElevationGridNode.h"
#include "ExtrusionNode.h"
#include "FogNode.h"
#include "FontStyleNode.h"
#include "GroupNode.h"
#include "ImageTextureNode.h"
#include "IndexedFaceSetNode.h"
#include "IndexedLineSetNode.h"
#include "InlineNode.h"
#include "LodNode.h"
#include "MaterialNode.h"
#include "MovieTextureNode.h"
#include "NavigationInfoNode.h"
#include "NormalNode.h"
#include "NormalInterpolatorNode.h"
#include "OrientationInterpolatorNode.h"
#include "PixelTextureNode.h"
#include "PlaneSensorNode.h"
#include "PointLightNode.h"
#include "PointSetNode.h"
#include "PositionInterpolatorNode.h"
#include "ProximitySensorNode.h"
#include "ScalarInterpolatorNode.h"
#include "ScriptNode.h"
#include "ShapeNode.h"
#include "SoundNode.h"
#include "SphereNode.h"
#include "SphereSensorNode.h"
#include "SpotLightNode.h"
#include "SwitchNode.h"
#include "TextNode.h"
#include "TextureCoordinateNode.h"
#include "TextureTransformNode.h"
#include "TimeSensorNode.h"
#include "TouchSensorNode.h"
#include "TransformNode.h"
#include "ViewpointNode.h"
#include "VisibilitySensorNode.h"
#include "WorldInfoNode.h"

#endif //JMC

==> maverik-6.1.tar.gz: maverik-6.1/src/extras/VRML97/vrmlnodes.h <==
/*
 GNU Maverik - a system for managing display and interaction in 
               Virtual Environment applications.
 Copyright (C) 1999-2001 Advanced Interfaces Group

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA


 The authors can be contacted via:
 www   - http://aig.cs.man.ac.uk
 email - maverik@aig.cs.man.ac.uk
 mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
         University of Manchester, Manchester, M13 9PL, UK
*/


#include "mavlib_cvcomp.h"

/******************************************************************
*
*	VRML library for C++
*
*	Copyright (C) Satoshi Konno 1996-1997
*
*	File:	vrmlnodes.h
*
******************************************************************/

#ifndef _VRMLNODE_H_
#define _VRMLNODE_H_

#include "RootNode.h"
#include "DefNode.h"

#include "AnchorNode.h"
#include "AppearanceNode.h"
#include "AudioClipNode.h"
#include "BackgroundNode.h"
#include "BillboardNode.h"
#include "BoxNode.h"
#include "CollisionNode.h"
#include "ColorNode.h"
#include "ColorInterpolatorNode.h"
#include "ConeNode.h"
#include "CoordinateNode.h"
#include "CoordinateInterpolatorNode.h"
#include "CylinderNode.h"
#include "CylinderSensorNode.h"
#include "DirectionalLightNode.h"
#include "ElevationGridNode.h"
#include "ExtrusionNode.h"
#include "FogNode.h"
#include "FontStyleNode.h"
#include "GroupNode.h"
#include "ImageTextureNode.h"
#include "IndexedFaceSetNode.h"
#include "IndexedLineSetNode.h"
#include "InlineNode.h"
#include "LodNode.h"
#include "MaterialNode.h"
#include "MovieTextureNode.h"
#include "NavigationInfoNode.h"
#include "NormalNode.h"
#include "NormalInterpolatorNode.h"
#include "OrientationInterpolatorNode.h"
#include "PixelTextureNode.h"
#include "PlaneSensorNode.h"
#include "PointLightNode.h"
#include "PointSetNode.h"
#include "PositionInterpolatorNode.h"
#include "ProximitySensorNode.h"
#include "ScalarInterpolatorNode.h"
#include "ScriptNode.h"
#include "ShapeNode.h"
#include "SoundNode.h"
#include "SphereNode.h"
#include "SphereSensorNode.h"
#include "SpotLightNode.h"
#include "SwitchNode.h"
#include "TextNode.h"
#include "TextureCoordinateNode.h"
#include "TextureTransformNode.h"
#include "TimeSensorNode.h"
#include "TouchSensorNode.h"
#include "TransformNode.h"
#include "ViewpointNode.h"
#include "VisibilitySensorNode.h"
#include "WorldInfoNode.h"

#endif //JMC
